<template>
  <!-- 安全工作目标信息添加 -->
  <div>
    <el-dialog
      :before-close="handleClose"
      :close-on-click-modal="false"
      :title=" '安全隐患检查(节假日)'"
      :visible.sync="showFormDia"
      top="8vh"
      width="76%"
    >
      <div>
        <el-form ref="formInfo" :model="params" :rules="rules" label-width="120px">
          <p id="step1" class="from-title">
            <i class="el-icon-info" />
            <span>安全隐患检查基础信息</span>
          </p>
          <el-row>
            <el-col :span="8">
              <el-form-item :span="13" label="受检单位名称" prop="clientUnitName">
                <el-input v-model="params.clientUnitName" :disabled="true" clearable placeholder="请选择受检单位名称">
                  <template #append>
                    <el-button icon="el-icon-s-check" type="info" @click="addTable" />
                  </template>
                </el-input>
              </el-form-item>
            </el-col>
            <el-col :span="8">
              <el-form-item label="受检单位负责人" prop="clientUserName">
                <el-input v-model="params.clientUserName" placeholder="请输入">
                </el-input>
              </el-form-item>
            </el-col>
            <el-col :span="8">
              <el-form-item label="联系电话" prop="clientTel">
                <el-input v-model="params.clientTel" placeholder="请输入"></el-input>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row>
            <el-col :span="8">
              <el-form-item label="检查人员" prop="examineUserName">
                <el-input v-model="params.examineUserName" placeholder="请输入检查人员"></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="8">
              <el-form-item label="检查时间" prop="clientDate">
                <el-date-picker
                  v-model="params.clientDate"
                  placeholder="选择日期"
                  type="date"
                  value-format="yyyy-MM-dd">
                </el-date-picker>
              </el-form-item>
            </el-col>
          </el-row>
          <p id="step1" class="from-title">
            <i class="el-icon-info" />
            <span>问题隐患信息</span>
          </p>
          <el-row>
            <el-col :span="24">
              <el-form-item>
                <el-table :data="params.details" style="width: 100%">
                  <el-table-column label="问题隐患" prop="name"></el-table-column>
                  <el-table-column header-align="center" label="是否存在隐患">
                    <template slot-scope="scope">
                      <div class="radio-container">
                        <el-radio v-model="scope.row.indexValue" :label="1" @change="handleRadioChange(scope.row)">存在
                        </el-radio>
                        <el-radio v-model="scope.row.indexValue" :label="0" @change="handleRadioChange(scope.row)">
                          不存在
                        </el-radio>
                      </div>
                    </template>
                  </el-table-column>
                  <el-table-column label="备注">
                    <template slot-scope="scope">
                      <el-input
                        v-model="scope.row.remarks"
                        maxlength="500"
                        placeholder="请输入备注"
                        show-word-limit
                        type="textarea"
                      ></el-input>
                    </template>
                  </el-table-column>
                </el-table>
              </el-form-item>
            </el-col>
          </el-row>
          <el-form-item>
            <div class="rectification-requirements">
              <p>
                对以上第<span class="underline">
              <el-input v-model="params.hiddenValue" class="inline-input" placeholder="填写"></el-input>
            </span>条火灾、燃气安全隐患（违法行为），你（单位）应立即采取措施进行整改消除；
                应在<span class="underline">
              <el-input v-model="params.changesYear" class="inline-input" placeholder="年"></el-input>
            </span>年<span class="underline">
              <el-input v-model="params.changesMonth" class="inline-input" placeholder="月"></el-input>
            </span>月<span class="underline">
              <el-input v-model="params.changesDay" class="inline-input" placeholder="日"></el-input>
            </span>日前整改完毕。
                在安全隐患（违法行为）消除前，应当采取确保消防安全、防止火灾发生的措施。
              </p>
            </div>
          </el-form-item>
        </el-form>
      </div>
      <span slot="footer" class="dialog-footer">
        <el-button :loading="loading" type="primary" @click="handleSave">保 存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
      <CmgtSaftyDangerCheckplanFormDialogTroubleshooting
        ref="troubleshooting"
        :title="'计划'"
        @addDetail="addDetail"
      />
    </el-dialog>
  </div>
</template>
<script>
import dictUtils from '@/components/dict/DictSelectUtils.js'
import CmgtSaftyDangerCheckplanFormDialogTroubleshooting
  from '@/views/Manage/saftyPlan/components/CmgtSaftyDangerCheckplanFormDialogTroubleshooting.vue'
import API from '@/views/Manage/saftyPlan/api/CmgTSaftyHazardCheckApi'
import nineLittlePlaceApi from '@/views/Manage/saftyDanger/api/nineLittlePlaceApi'

export default {
  name: 'CmgtSaftyTargetFormDialog',
  components: {CmgtSaftyDangerCheckplanFormDialogTroubleshooting},
  props: {},
  // components: {fileUpload},
  data() {
    return {
      // title: '是否',
      showFormDia: false,
      loading: false,
      activeCollapseNames: ['1'],
      activeTabChildName: '0',
      tableData: [],
      previewUrl:
        window.context.portal +
        '/file/onlinePreviewController/v1/getFileById_',
      params: {
        unitName: '',
        //
        clientUnitName: '', // 受检单位名称
        clientUnitId: '', // 新增：受检单位 ID
        clientUserName: '', // 受检单位负责人
        clientTel: '', // 联系电话
        examineUserName: '', // 检查人员
        clientDate: '', // 检查时间
        hiddenValue: '', // 问题编号
        changesYear: '', // 年
        changesMonth: '', // 月
        changesDay: '' // 日
        // details: [] // 问题隐患信息
      },
      rules: {
        clientUnitName: [{required: true, message: '受检单位名称不能为空', trigger: 'change'}],
        clientUserName: [{required: true, message: '受检单位负责人不能为空', trigger: 'change'}],
        clientTel: [{required: true, message: '联系电话不能为空', trigger: 'change'}],
        examineUserName: [{required: true, message: '检查人员不能为空', trigger: 'blur'}],
        clientDate: [{required: true, message: '检查时间不能为空', trigger: 'blur'}]
      },
      zbkhfsList: [],
      aqywlbList: [],
      unitList: []
    }
  },
  created() {
    this.zbkhfsList = dictUtils.getDictItemsFromCache('zbkhfs')
    this.aqywlbList = dictUtils.getDictItemsFromCache('aqywlb')
    // 获取 jjrpc_yhlx 字典数据
    const jjrpcYhlxList = dictUtils.getDictItemsFromCache('jjrpc_yhlx')
    if (jjrpcYhlxList && jjrpcYhlxList.length > 0) {
      // 将字典数据映射到 params.details 中
      this.params.details = jjrpcYhlxList.slice(0, 11).map(item => ({
        dictValue: item.value, // 假设字典项的 name 字段是描述
        name: item.name, // 使用字典中的 value 作为 dictvalue
        indexValue: 0, // 默认不存在
        remarks: '',// 备注为空
        sequence: item.sequence // 新增：获取数据序号
        //sequence为序号
      }))
    }
    this.fill()
  },
  methods: {
    handleRadioChange(row) {
      // 过滤出存在隐患的数据
      const existIssues = this.params.details.filter(item => item.indexValue === 1)

      // 获取这些数据的 sequence
      const sequences = existIssues.map(item => item.sequence)

      // 将 sequence 拼接成字符串，填充到 hiddenValue
      this.params.hiddenValue = sequences.join(', ')
    },
    fill() {
      let queryParam = {
        'pageBean': {
          'pageSize': -1,
          'page': 1
        },
        'params': {},
        'querys': [
          {
            'group': 'main',
            'operation': 'LIKE',
            'parentGroup': '',
            'property': 'type_',
            'relation': 'AND',
            'value': 1
          }
        ],
        'sorter': [
          {
            'direction': 'DESC',
            'property': 'createTime'
          }
        ]
      }
      nineLittlePlaceApi.loadCmgtSaftyDangerUnit(queryParam).then(res => {
        this.unitList = res.data.rows
      })
    },
    addTable() {
      this.$refs.troubleshooting.add()
      // this.$refs.singleTable.setCurrentRow(this.tableData[this.tableData.length - 1])
    },
    Update(row) {
      // this.params = {...row}
      if (row.id) {
        this.title = '修改'
        this.showFormDia = true
        API.getItemById(row.id, res => {
          console.log('通过 id 获取的数据:', res)
          if (res) {
            this.params = res
            this.params.clientUnitName = this.unitList.filter(item => item.id === this.params.clientUnitId)[0].unitName
            this.params.details = res.details.map(item => {
              return {
                name: item.dictName,
                indexValue: Number(item.indexValue),
                dictValue: Number(item.dictValue),
                remarks: item.remarks,
                id: item.id
              }
            })
            console.log(this.params, '----------------------')
            console.log('res.details:', res.details)
            console.log('this.params.details:', this.params.details)
          } else {
            console.error('通过 id 获取数据失败')
          }
        })
      } else {
        console.error('行数据中缺少 id 字段')
      }

    },
    resetForm() {
      this.params = {
        id: null, // 新增这一行
        ...this.params,
        clientUnitName: '',
        clientUserName: '',
        clientTel: '',
        examineUserName: '',
        clientDate: '',
        hiddenValue: '',
        changesYear: '',
        changesMonth: '',
        changesDay: '',
        remarks: ''
        // details: [],
        // indexValue: ''
      }
    },
    addDetail(list) {
      console.log('接收到的数据', list)
      if (list.length > 0) {
        const selectedData = list[0] // 假设只选择一条数据
        this.params.clientUnitName = selectedData.unitName // 商户名称赋值给受检单位名称
        this.params.clientUserName = selectedData.name // 负责人赋值给受检单位负责人
        this.params.clientTel = selectedData.phone // 联系电话赋值给联系电话
        this.params.clientUnitId = selectedData.id // 新增：获取受检单位 ID
        console.log('更新后的form', this.params)
      }
    },

    attachmentUploadSuccess(res, file, fileList) {
      if (res.success) {
        this.params.fileList.push({
          name: res.fileName,
          id: res.fileId,
          url: this.previewUrl + res.fileId,
          extensionName: file.name.substring(
            file.name.lastIndexOf('.') + 1
          )
        })
      } else {
        this.$message.error('上传文件失败！')
      }
    },
    add() {
      this.title = '新增'
      this.resetForm()
      // 清空 details 数组
      this.params.details = []
      this.params.id = null // 新增这一行
      // 重新初始化 details 数据
      const jjrpcYhlxList = dictUtils.getDictItemsFromCache('jjrpc_yhlx')
      if (jjrpcYhlxList && jjrpcYhlxList.length > 0) {
        this.params.details = jjrpcYhlxList.slice(0, 11).map(item => ({
          dictValue: item.value,
          name: item.name,
          indexValue: 0,
          remarks: '',
          sequence: item.sequence
        }))
      }
      this.showFormDia = true
    },


    handleSave() {
      console.log('提交数据1111', this.params)

      // alert('数据已提交！')
      this.$refs.formInfo.validate(valid => {
        if (!valid) {
          this.$message.warning('请填写完整必填项')
          return
        }

        // 校验 details 中的每一项
        const isDetailsValid = this.params.details.every(item => {
          return item.indexValue !== undefined && item.indexValue !== null
        })

        if (!isDetailsValid) {
          this.$message.warning('请勾选所有问题隐患')
          return
        }
        // 如果校验通过，执行保存逻辑
        let method = !this.params.id ? API.addAction : API.editCmgtSaftyTarget

        this.loading = true
        method(this.params, res => {
          console.log('/////', res)
          this.loading = false
          if (res.state) {
            this.$notify({
              type: 'success',
              message: this.title + '成功',
              duration: 2000
            })
            this.$emit('save-success')
            // this.$parent.loadData()
            // this.handleClose()// 保存成功后再关闭弹窗
            this.showFormDia = false// 关闭弹窗
          } else {
            this.$message.warning(res.message)
          }
        })

      })
    },
    handleClose() {
      this.resetForm()// 重置表单数据
      this.$refs.formInfo.resetFields()// 重置表单验证状态
      // this.params = {}
      this.showFormDia = false// 关闭弹窗
    }
  }
}
</script>
<style lang="scss" scoped>

.dialog-footer {
  text-align: center;
}

.rectification-requirements {
  font-size: 14px;
  color: #606266;
  line-height: 1.5;
  margin-bottom: 20px;
  margin-left: -100px !important;
}

.underline {
  display: inline-block;
  margin: 0 4px;
}

.inline-input {
  width: 80px; /* 调整输入框宽度 */
  display: inline-block;
}


::v-deep .el-form-item:has(.el-table) {
  margin-left: -120px; // 将包含 el-table 的 el-form-item 的 margin-left 改为 20px
}

.radio-container {
  text-align: center;
}
</style>
